@@ -14,8 +14,17 @@
 # limitations under the License.
 # =============================================================================
 
+from nemo.collections.nlp.nm.trainables.common.common_utils import *
+from nemo.collections.nlp.nm.trainables.common.encoder_rnn import *
 from nemo.collections.nlp.nm.trainables.common.huggingface import *
 from nemo.collections.nlp.nm.trainables.common.sequence_classification_nm import *
 from nemo.collections.nlp.nm.trainables.common.sequence_regression_nm import *
 from nemo.collections.nlp.nm.trainables.common.token_classification_nm import *
 from nemo.collections.nlp.nm.trainables.common.transformer import *
+from nemo.utils import logging
+
+try:
+    from nemo.collections.nlp.nm.trainables.common.megatron.megatron_utils import *
+
+except Exception as e:
+    logging.error('Failed to import Megatron utils: `{}` ({})'.format(str(e), type(e)))
